pub struct SessionGuard { /* private fields */ }Expand description
RAII guard for session-scoped transactions.
Created via SessionGuard::begin(), which calls control.begin().
On drop, automatically calls control.rollback() unless commit()
was called first.
Implementations
Sourceimpl SessionGuard
impl SessionGuard
Sourcepub async fn begin(control: Arc<dyn SessionControl>) -> Result<Self, IndexError>
pub async fn begin(control: Arc<dyn SessionControl>) -> Result<Self, IndexError>
Begin a new session, returning an RAII guard.
Calls control.begin() and returns a guard that will automatically
roll back on drop unless commit() is called.
Sourcepub async fn commit(self) -> Result<(), IndexError>
pub async fn commit(self) -> Result<(), IndexError>
Commit the session-scoped transaction.
Marks the guard as committed so that Drop will not roll back.
The committed flag is set only after a successful commit — if
control.commit() fails, Drop will still trigger rollback.