pub struct SourceCheckpoint {
pub sequence: u64,
pub source_position: Option<Bytes>,
}Expand description
Per-source checkpoint data.
Contains the monotonic sequence number and an optional opaque position that the source interprets to seek back into its native change stream (e.g., Postgres LSN, Kafka offset, EventHub sequence number).
Fields
sequence: u64source_position: Option<Bytes>Opaque position bytes for native stream resumption. Sources interpret these to seek back into their change stream.
Implementations